==> SQLiteCSLib_Src_1_4.zip: SQLiteCSLib_Src_1_4/1.x/osqlite/osqlite3__stmt_if.cpp <==
/*
*** SQLITE3 STMT bp[
***
*** CC^[tF[X GLX|[g
*/

#include "stdafx.h"

/*
*** CX^X쐬
*/
__EXPORT osqlite3_stmt* WINAPI osqlite3_stmt_new( osqlite3* dbwrap )
{
	return new osqlite3_stmt( dbwrap );
}

/*
*** fXgN^
*/
__EXPORT void WINAPI osqlite3_stmt_delete( osqlite3_stmt* instance )
{
	delete instance;
}

/*
*** SQLPs
*** sql : SQL
*/
__EXPORT bool WINAPI osqlite3_stmt_execute( osqlite3_stmt* instance, wchar_t* sql )
{
	return instance->execute( sql );
}

/*
*** SQLs\
*** sql : SQL
*/
__EXPORT bool WINAPI osqlite3_stmt_prepare( osqlite3_stmt* instance, wchar_t* sql )
{
	return instance->prepare( sql );
}

/*
*** \(prepare)s
*** J[\s
*/
__EXPORT int WINAPI osqlite3_stmt_step( osqlite3_stmt* instance )
{
	return instance->step();
}

/*
*** f[^ʃJEg
*** step̌݃JEg
*/
__EXPORT int WINAPI osqlite3_stmt_data_count( osqlite3_stmt* instance )
{
	return instance->data_count();
}

/*
*** f[^ʃJJEg
*/
__EXPORT int WINAPI osqlite3_stmt_column_count( osqlite3_stmt* instance )
{
	return instance->column_count();
}

/*
*** J^Cv擾
*** ߒl:<sqlite3.h>Q
*/
__EXPORT int WINAPI osqlite3_stmt_getType( osqlite3_stmt* instance, int icol )
{
	return instance->getType( icol );
}

/*
*** ^l擾
*/
__EXPORT int WINAPI osqlite3_stmt_getInt( osqlite3_stmt* instance, int icol )
{
	return instance->getInt( icol );
}

#ifdef _WIN32_WCE
/*
*** ^l擾
*/
__EXPORT void WINAPI osqlite3_stmt_getInt64( osqlite3_stmt* instance, int icol, sqlite3_int64* lVal )
{
	*lVal = instance->getInt64( icol );
}

/*
*** _l擾
*/
__EXPORT void WINAPI osqlite3_stmt_getDouble( osqlite3_stmt* instance, int icol, double* dVal )
{
	*dVal = instance->getDouble( icol );
}
#else
/*
*** ^l擾
*/
__EXPORT sqlite3_int64 WINAPI osqlite3_stmt_getInt64( osqlite3_stmt* instance, int icol )
{
	return instance->getInt64( icol );
}

/*
*** _l擾
*/
__EXPORT double WINAPI osqlite3_stmt_getDouble( osqlite3_stmt* instance, int icol )
{
	return instance->getDouble( icol );
}
#endif

/*
*** l擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_stmt_getText( osqlite3_stmt* instance, int icol )
{
	return instance->getText( icol );
}

/*
*** BLOBl擾
*/
__EXPORT const void* WINAPI osqlite3_stmt_getBlob( osqlite3_stmt* instance, int icol, int* valsize )
{
	return instance->getBlob( icol, *valsize );
}

/*
*** J擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_stmt_getColumnName( osqlite3_stmt* instance, int icol )
{
	return instance->getColumnName( icol );
}

/*
*** J̃e[u擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_stmt_getColumnTableName( osqlite3_stmt* instance, int icol )
{
	return instance->getColumnTableName( icol );
}

/*
*** BLOBTCY擾
*/
__EXPORT int WINAPI osqlite3_stmt_getSize( osqlite3_stmt* instance, int icol )
{
	return instance->getSize( icol );
}

/*
*** oChϐZbg
*/
__EXPORT bool WINAPI osqlite3_stmt_reset( osqlite3_stmt* instance )
{
	return instance->reset( );
}

/*
*** ^UoCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindBool( osqlite3_stmt* instance, int icol, bool val )
{
	return instance->bindBool( icol, val );
}

/*
*** oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindInt( osqlite3_stmt* instance, int icol, int val )
{
	return instance->bindInt( icol, val );
}

#ifdef _WIN32_WCE
/*
*** oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindInt64( osqlite3_stmt* instance, int icol, sqlite3_int64* val )
{
	return instance->bindInt64( icol, *val );
}

/*
*** _oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindDouble( osqlite3_stmt* instance, int icol, double* val )
{
	return instance->bindDouble( icol, *val );
}

/*
*** oCh
*** _ELXg
*/
__EXPORT bool WINAPI osqlite3_stmt_bindDecimal( osqlite3_stmt* instance, int icol, long double* val )
{
	return instance->bindDecimal( icol, *val );
}

#else
/*
*** oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindInt64( osqlite3_stmt* instance, int icol, sqlite3_int64 val )
{
	return instance->bindInt64( icol, val );
}

/*
*** _oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindDouble( osqlite3_stmt* instance, int icol, double val )
{
	return instance->bindDouble( icol, val );
}

/*
*** oCh
*** _ELXg
*/
__EXPORT bool WINAPI osqlite3_stmt_bindDecimal( osqlite3_stmt* instance, int icol, long double val )
{
	return instance->bindDecimal( icol, val );
}
#endif

/*
*** oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindText( osqlite3_stmt* instance, int icol, wchar_t* val )
{
	return instance->bindText( icol, val );
}

/*
*** NULLoCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindNull( osqlite3_stmt* instance, int icol )
{
	return instance->bindNull( icol );
}

/*
*** BloboCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindBlob( osqlite3_stmt* instance, int icol, void* val, int valsize )
{
	return instance->bindBlob( icol, val, valsize );
}

==> SQLiteCSLib_Src_1_5.zip: SQLiteCSLib_Src_1_5/1.x/osqlite/osqlite3__stmt_if.cpp <==
/*
*** SQLITE3 STMT bp[
***
*** CC^[tF[X GLX|[g
*/

#include "stdafx.h"

/*
*** CX^X쐬
*/
__EXPORT osqlite3_stmt* WINAPI osqlite3_stmt_new( osqlite3* dbwrap )
{
	return new osqlite3_stmt( dbwrap );
}

/*
*** fXgN^
*/
__EXPORT void WINAPI osqlite3_stmt_delete( osqlite3_stmt* instance )
{
	delete instance;
}

/*
*** SQLPs
*** sql : SQL
*/
__EXPORT bool WINAPI osqlite3_stmt_execute( osqlite3_stmt* instance, wchar_t* sql )
{
	return instance->execute( sql );
}

/*
*** SQLs\
*** sql : SQL
*/
__EXPORT bool WINAPI osqlite3_stmt_prepare( osqlite3_stmt* instance, wchar_t* sql )
{
	return instance->prepare( sql );
}

/*
*** \(prepare)s
*** J[\s
*/
__EXPORT int WINAPI osqlite3_stmt_step( osqlite3_stmt* instance )
{
	return instance->step();
}

/*
*** f[^ʃJEg
*** step̌݃JEg
*/
__EXPORT int WINAPI osqlite3_stmt_data_count( osqlite3_stmt* instance )
{
	return instance->data_count();
}

/*
*** f[^ʃJJEg
*/
__EXPORT int WINAPI osqlite3_stmt_column_count( osqlite3_stmt* instance )
{
	return instance->column_count();
}

/*
*** J^Cv擾
*** ߒl:<sqlite3.h>Q
*/
__EXPORT int WINAPI osqlite3_stmt_getType( osqlite3_stmt* instance, int icol )
{
	return instance->getType( icol );
}

/*
*** ^l擾
*/
__EXPORT int WINAPI osqlite3_stmt_getInt( osqlite3_stmt* instance, int icol )
{
	return instance->getInt( icol );
}

#ifdef _WIN32_WCE
/*
*** ^l擾
*/
__EXPORT void WINAPI osqlite3_stmt_getInt64( osqlite3_stmt* instance, int icol, sqlite3_int64* lVal )
{
	*lVal = instance->getInt64( icol );
}

/*
*** _l擾
*/
__EXPORT void WINAPI osqlite3_stmt_getDouble( osqlite3_stmt* instance, int icol, double* dVal )
{
	*dVal = instance->getDouble( icol );
}
#else
/*
*** ^l擾
*/
__EXPORT sqlite3_int64 WINAPI osqlite3_stmt_getInt64( osqlite3_stmt* instance, int icol )
{
	return instance->getInt64( icol );
}

/*
*** _l擾
*/
__EXPORT double WINAPI osqlite3_stmt_getDouble( osqlite3_stmt* instance, int icol )
{
	return instance->getDouble( icol );
}
#endif

/*
*** l擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_stmt_getText( osqlite3_stmt* instance, int icol )
{
	return instance->getText( icol );
}

/*
*** BLOBl擾
*/
__EXPORT const void* WINAPI osqlite3_stmt_getBlob( osqlite3_stmt* instance, int icol, int* valsize )
{
	return instance->getBlob( icol, *valsize );
}

/*
*** J擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_stmt_getColumnName( osqlite3_stmt* instance, int icol )
{
	return instance->getColumnName( icol );
}

/*
*** J̃e[u擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_stmt_getColumnTableName( osqlite3_stmt* instance, int icol )
{
	return instance->getColumnTableName( icol );
}

/*
*** J̌̎擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_stmt_getColumnOriginalName( osqlite3_stmt* instance, int icol )
{
	return instance->getColumnOriginalName( icol );
}

/*
*** J̐錾擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_stmt_getColumnDecltype( osqlite3_stmt* instance, int icol )
{
	return instance->getColumnDecltype( icol );
}

/*
*** BLOBTCY擾
*/
__EXPORT int WINAPI osqlite3_stmt_getSize( osqlite3_stmt* instance, int icol )
{
	return instance->getSize( icol );
}

/*
*** oChϐZbg
*/
__EXPORT bool WINAPI osqlite3_stmt_reset( osqlite3_stmt* instance )
{
	return instance->reset( );
}

/*
*** ^UoCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindBool( osqlite3_stmt* instance, int icol, bool val )
{
	return instance->bindBool( icol, val );
}

/*
*** oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindInt( osqlite3_stmt* instance, int icol, int val )
{
	return instance->bindInt( icol, val );
}

#ifdef _WIN32_WCE
/*
*** oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindInt64( osqlite3_stmt* instance, int icol, sqlite3_int64* val )
{
	return instance->bindInt64( icol, *val );
}

/*
*** _oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindDouble( osqlite3_stmt* instance, int icol, double* val )
{
	return instance->bindDouble( icol, *val );
}

/*
*** oCh
*** _ELXg
*/
__EXPORT bool WINAPI osqlite3_stmt_bindDecimal( osqlite3_stmt* instance, int icol, long double* val )
{
	return instance->bindDecimal( icol, *val );
}

#else
/*
*** oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindInt64( osqlite3_stmt* instance, int icol, sqlite3_int64 val )
{
	return instance->bindInt64( icol, val );
}

/*
*** _oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindDouble( osqlite3_stmt* instance, int icol, double val )
{
	return instance->bindDouble( icol, val );
}

/*
*** oCh
*** _ELXg
*/
__EXPORT bool WINAPI osqlite3_stmt_bindDecimal( osqlite3_stmt* instance, int icol, long double val )
{
	return instance->bindDecimal( icol, val );
}
#endif

/*
*** oCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindText( osqlite3_stmt* instance, int icol, wchar_t* val )
{
	return instance->bindText( icol, val );
}

/*
*** NULLoCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindNull( osqlite3_stmt* instance, int icol )
{
	return instance->bindNull( icol );
}

/*
*** BloboCh
*/
__EXPORT bool WINAPI osqlite3_stmt_bindBlob( osqlite3_stmt* instance, int icol, void* val, int valsize )
{
	return instance->bindBlob( icol, val, valsize );
}
